@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.17 2005/10/30 19:21:10 chpe Exp $
+ *  $Id: error-viewer.c 1629 2007-11-04 00:07:29Z cyrilbois $
  */
 
 #include "config.h"
@@ -70,7 +70,7 @@ static GObjectClass *parent_class = NULL;
 
 static GType type = 0;
 
-GType 
+GType
 error_viewer_get_type (void)
 {
 	return type;
@@ -79,7 +79,7 @@ error_viewer_get_type (void)
 GType
 error_viewer_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (ErrorViewerClass),
 		NULL, /* base_init */
@@ -200,7 +200,7 @@ response_cb (GtkWidget *widget,
 	{
 		gtk_list_store_clear (GTK_LIST_STORE (priv->model));
 		gtk_tree_view_columns_autosize (GTK_TREE_VIEW (priv->treeview));
-	
+
 		return;
 	}
 
@@ -265,7 +265,7 @@ build_ui (ErrorViewer *dialog)
 
 static void
 error_viewer_init (ErrorViewer *dialog)
-{		
+{
 	dialog->priv = ERROR_VIEWER_GET_PRIVATE (dialog);
 
 	dialog->priv->num_active = 0;
