@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,16 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.h,v 1.1 2004/02/22 18:54:33 adamh Exp $
+ *  $Id: mozilla-helpers.h 1726 2008-05-18 21:51:05Z chpe $
  */
 
 #ifndef ERROR_VIEWER_MOZILLA_HELPERS_H
 #define ERROR_VIEWER_MOZILLA_HELPERS_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <glib.h>
 
 #include <epiphany/ephy-embed.h>
@@ -39,6 +35,8 @@ GSList		*mozilla_get_links		(EphyEmbed *embed);
 
 gboolean	mozilla_check_url		(EphyEmbed *embed, char *url);
 
+gboolean       mozilla_glue_startup             (void);
+
 G_END_DECLS
 
 #endif
