@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-link-checker.cpp 1703 2008-03-26 21:59:12Z chpe $
+ *  $Id: mozilla-link-checker.cpp 1726 2008-05-18 21:51:05Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -45,7 +45,7 @@ mozilla_check_links (LinkChecker *checker,
 	nsresult rv;
 
 	nsCOMPtr<nsIWebBrowser> browser;
-	gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (embed),
+	gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (embed))),
 					 getter_AddRefs (browser));
 	NS_ENSURE_TRUE (browser, );
 
