@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.25 2006/09/13 19:01:07 chpe Exp $
+ *  $Id: sgml-validator.c 1427 2006-12-31 16:51:24Z chpe $
  */
 
 #include "config.h"
@@ -402,7 +402,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 
 	unlink (dest);
 
-	if (!g_thread_supported ()) g_thread_init (NULL);
+	g_assert (g_thread_supported ());
 
 	data = g_new0 (OpenSPThreadCBData, 1);
 	data->dest = dest_utf8;
