@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.20.2.1 2006/04/09 20:24:24 chpe Exp $
+ *  $Id: extensions-manager-ui.c 1521 2007-05-16 13:05:56Z chpe $
  */
 
 #include "config.h"
@@ -98,7 +98,7 @@ extensions_manager_ui_get_type (void)
 GType
 extensions_manager_ui_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (ExtensionsManagerUIClass),
 		NULL, /* base_init */
@@ -149,23 +149,22 @@ show_extension_info (ExtensionsManagerUI *parent_dialog,
 	url = g_key_file_get_string (keyfile, GROUP, "URL", NULL);
 	authors = g_key_file_get_string_list (keyfile, GROUP, "Authors", NULL, NULL);
 
-	dialog = GTK_ABOUT_DIALOG (gtk_about_dialog_new ());
-	gtk_about_dialog_set_name (dialog, name);
-	gtk_about_dialog_set_comments (dialog, description);
-	gtk_about_dialog_set_website (dialog, url);
-	gtk_about_dialog_set_authors (dialog, (const char **) authors);
+	dialog = g_object_new (GTK_TYPE_ABOUT_DIALOG,
+#if GTK_CHECK_VERSION (2, 11, 0)
+                               "program-name", name,
+#else
+#endif /* GTK 2.11.0 */
+                               "name", name,
+                               "comments", description,
+                               "website", url,
+                               "authors", (const char **) authors,
+                               NULL);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				      GTK_WINDOW (parent_dialog->priv->window));
-#if !GTK_CHECK_VERSION(2,9,0)
-	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent_dialog->priv->window)),
-				     GTK_WINDOW (dialog));
-#endif
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
-#if GTK_CHECK_VERSION(2,9,0)
 	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-#endif
 
 	gtk_window_present (GTK_WINDOW (dialog));
 
@@ -344,6 +343,7 @@ build_ui (ExtensionsManagerUI *dialog)
 	gtk_window_set_icon_name (GTK_WINDOW (priv->window), GTK_STOCK_PREFERENCES);
 
 	treeview = GTK_TREE_VIEW (priv->treeview);
+	gtk_tree_view_set_rules_hint (treeview, TRUE);
 
 	g_signal_connect (G_OBJECT (treeview), "row-activated",
 			  G_CALLBACK (row_activated), dialog);
