@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c 1626 2007-11-03 23:36:52Z cyrilbois $
+ *  $Id: extension.c 1727 2008-05-18 21:51:10Z chpe $
  */
 
 #include "config.h"
 
 #include "greasemonkey-script.h"
 #include "ephy-greasemonkey-extension.h"
+#include "mozilla-helpers.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -35,6 +36,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyGreasemonkeyExtension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
         bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
