@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c 1376 2006-09-13 19:01:42Z chpe $
+ *  $Id: extension.c 1729 2008-05-18 21:51:22Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-livehttpheaders-extension.h"
+#include "mozilla-helper.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -34,6 +35,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyLivehttpheadersExtension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
         bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
