@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.5 2006/09/13 19:01:22 chpe Exp $
+ *  $Id: extension.c 1725 2008-05-18 21:51:00Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-page-info-extension.h"
 #include "page-info-dialog.h"
+#include "mozilla-helpers.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -34,6 +35,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyPageInfoExtension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
