@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: PageInfoPrivate.cpp,v 1.3 2006/09/13 19:01:22 chpe Exp $
+ *  $Id: PageInfoPrivate.cpp 1707 2008-03-27 14:28:05Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -23,24 +23,36 @@
 
 #include <nscore.h>
 
+#ifdef HAVE_GECKO_1_9
+#include <nsStringGlue.h>
+#else
 #define MOZILLA_INTERNAL_API 1
 #include <nsString.h>
+#endif /* HAVE_GECKO_1_9 */
 
 #include <nsCOMPtr.h>
 #include <nsIDOMDocument.h>
+#ifdef HAVE_GECKO_1_9
+#include <nsIDocument.h>
+#else
 #include <nsIHTMLDocument.h>
+#endif
 
 #include "PageInfoPrivate.h"
 
 EmbedPageRenderMode
 PageInfoPrivate::GetRenderMode (nsIDOMDocument *aDocument)
 {
-  nsCOMPtr<nsIHTMLDocument> htmlDoc (do_QueryInterface (aDocument));
+#ifdef HAVE_GECKO_1_9
+  nsCOMPtr<nsIDocument> doc (do_QueryInterface (aDocument));
+#else
+  nsCOMPtr<nsIHTMLDocument> doc (do_QueryInterface (aDocument));
+#endif
 
   EmbedPageRenderMode mode = EMBED_RENDER_UNKNOWN;
-  if (htmlDoc)
+  if (doc)
     {
-      mode = (EmbedPageRenderMode) htmlDoc->GetCompatibilityMode ();
+      mode = (EmbedPageRenderMode) doc->GetCompatibilityMode ();
     }
 
   return mode;
