@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Raphaël Slinckx <raphael@slinckx.net>
+ *  Copyright © 2005 Raphaël Slinckx <raphael@slinckx.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-rss-extension.c,v 1.13 2006/07/09 13:48:45 jframeau Exp $
+ *  $Id: ephy-rss-extension.c 1677 2008-02-22 18:17:03Z xan $
  */
 
 #include "config.h"
@@ -32,13 +32,13 @@
 #include <epiphany/ephy-statusbar.h>
 #include <epiphany/ephy-notebook.h>
 #include <epiphany/ephy-shell.h>
+#include <epiphany/ephy-embed-container.h>
 
 #include <gtk/gtkaction.h>
 #include <gtk/gtkactiongroup.h>
 #include <gtk/gtkuimanager.h>
 
 #include <gtk/gtkeventbox.h>
-#include <gtk/gtkframe.h>
 #include <gtk/gtkiconfactory.h>
 #include <gtk/gtkimage.h>
 
@@ -64,20 +64,14 @@ static GType type = 0;
 #define MENU_PATH	"/menubar/ToolsMenu"
 
 /* Status Bar stuff */
+#define FEED_ICON	"feed-presence"
 
-/* Test these
-	"stock_hyperlink-toolbar"	<-- Globe with a link
-	"stock_connect-to-url"		<-- Globe with a plug
-	"stock_internet"			<-- Simple globe
-*/
-#define STOCK_ICON	"stock_hyperlink-toolbar"
-
-static void ephy_rss_display_cb 	(GtkAction *action, 
+static void ephy_rss_display_cb 	(GtkAction *action,
 					 EphyWindow *window);
 static void ephy_rss_update_statusbar 	(EphyWindow *window,
 					 gboolean show);
 static void ephy_rss_update_action 	(EphyWindow *window);
-static void ephy_rss_feed_subscribe_cb (GtkAction *action, 
+static void ephy_rss_feed_subscribe_cb (GtkAction *action,
 					 EphyWindow *window);
 typedef struct
 {
@@ -87,7 +81,6 @@ typedef struct
 	GtkAction *subscribe_action;
 	guint ui_id;
 
-	GtkWidget *frame;
 	GtkWidget *evbox;
 } WindowData;
 
@@ -130,7 +123,7 @@ ephy_rss_ge_feed_cb (EphyEmbed *embed,
 }
 
 static void
-ephy_rss_feed_subscribe_cb (GtkAction *action, 
+ephy_rss_feed_subscribe_cb (GtkAction *action,
 			    EphyWindow *window)
 {
 	const GValue *value;
@@ -140,15 +133,13 @@ ephy_rss_feed_subscribe_cb (GtkAction *action,
 	EphyRssExtension *extension = EPHY_RSS_EXTENSION (g_object_get_data (
 												G_OBJECT (window),
 												EPHY_RSS_EXTENSION_DATA_KEY));
-	
+
 	LOG ("Subscribing to the feed");
 
 	event = ephy_window_get_context_event (window);
 	if (event == NULL) return;
-	
-	value = ephy_embed_event_get_property (event, "link");
 
-	
+	value = ephy_embed_event_get_property (event, "link");
 
 	if (!dbus_g_proxy_call (extension->priv->proxy, RSS_DBUS_SUBSCRIBE, &error,
 		G_TYPE_STRING, g_value_get_string (value),
@@ -159,37 +150,37 @@ ephy_rss_feed_subscribe_cb (GtkAction *action,
 		LOG ("Error while retreiving method answer: %s", error->message);
 		g_error_free (error);
 	}
-	
-	g_object_set(action, "sensitive", FALSE, "visible", FALSE, NULL);	
+
+	g_object_set(action, "sensitive", FALSE, "visible", FALSE, NULL);
 }
 
 static gboolean
 ephy_rss_ge_context_cb	(EphyEmbed *embed,
 			EphyEmbedEvent *event,
 			EphyWindow *window)
-{	
+{
 	WindowData *data;
 	const GValue *value;
 	const char *address;
 	FeedList *list;
 	gboolean active = FALSE;
-	
+
 	list = (FeedList *) g_object_get_data (G_OBJECT (embed), FEEDLIST_DATA_KEY);
 	if ((ephy_embed_event_get_context (event) & EPHY_EMBED_CONTEXT_LINK) && (list != NULL))
 	{
 		LOG ("Context menu on a link");
 		data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 		g_return_val_if_fail (data != NULL, FALSE);
-		
+
 		value = ephy_embed_event_get_property (event, "link");
 		address = g_value_get_string (value);
-		
+
 		active = rss_feedlist_contains (list, address);
-		
+
 		LOG ("Showing menu item: %d", active);
-		g_object_set(data->subscribe_action, "sensitive", active, "visible", active, NULL);	
+		g_object_set(data->subscribe_action, "sensitive", active, "visible", active, NULL);
 	}
-	
+
 	return FALSE;
 }
 
@@ -205,24 +196,24 @@ ephy_rss_dialog_display (EphyWindow *window)
 	g_return_if_fail (data != NULL);
 
 	priv = data->extension->priv;
-	
-	embed = ephy_window_get_active_embed (window);
+
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
-	
+
 	list = (FeedList *) g_object_get_data (G_OBJECT (embed), FEEDLIST_DATA_KEY);
 	if (list == NULL)
 		return;
-	
+
 	if (priv->dialog == NULL)
 	{
 		RssUI **dialog;
 
 		LOG ("Trying to build dialog");
-		
+
 		priv->dialog = rss_ui_new (list, embed);
 
 		dialog = &priv->dialog;
-		
+
 		g_object_add_weak_pointer (G_OBJECT (priv->dialog),
 					   (gpointer *) dialog);
 	}
@@ -262,9 +253,8 @@ ephy_rss_update_statusbar (EphyWindow *window,
 	/* Show / Hide statusbar icon */
 	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 	g_return_if_fail (data != NULL);
-	g_return_if_fail (data->frame != NULL);
-	
-	g_object_set (data->frame, "visible", show, NULL);
+
+	g_object_set (data->evbox, "visible", show, NULL);
 }
 
 /* Update the menu item availability */
@@ -276,7 +266,7 @@ ephy_rss_update_action (EphyWindow *window)
 	gboolean show = TRUE;
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 
 	/* The page is loaded, do we have a feed ? */
 	list = (FeedList *) g_object_get_data (G_OBJECT (embed), FEEDLIST_DATA_KEY);
@@ -290,10 +280,10 @@ ephy_rss_update_action (EphyWindow *window)
 	g_object_set (data->info_action, "sensitive", show, NULL);
 
 	ephy_rss_update_statusbar (window, show);
-	
-	g_object_set(data->subscribe_action, "sensitive", show, "visible", show, NULL);	
+
+	g_object_set(data->subscribe_action, "sensitive", show, "visible", show, NULL);
 }
-	
+
 /* Called when the user changes tab */
 static void
 ephy_rss_sync_active_tab (EphyWindow *window,
@@ -309,17 +299,14 @@ ephy_rss_sync_active_tab (EphyWindow *window,
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("Attach rss listener to tab");
 
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	/* Notify when a new rss feed is parsed */
-	g_signal_connect_after (embed, "ge-content-change",
+	g_signal_connect_after (embed, "new-document-now",
 				G_CALLBACK (ephy_rss_ge_content_cb), window);
 	g_signal_connect_after (embed, "ge-feed-link",
 			    G_CALLBACK (ephy_rss_ge_feed_cb), window);
@@ -327,18 +314,14 @@ impl_attach_tab (EphyExtension *extension,
 			    G_CALLBACK (ephy_rss_ge_context_cb), window);
 }
 
-                                             
 /* Stop listening for the detached tab rss feeds */
 static void
 impl_detach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("Detach tab rss listener");
 
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	/* We don't want any new rss notif for this tab */
@@ -347,10 +330,10 @@ impl_detach_tab (EphyExtension *extension,
 
 	g_signal_handlers_disconnect_by_func
 		(embed, G_CALLBACK (ephy_rss_ge_content_cb), window);
-	
+
 	g_signal_handlers_disconnect_by_func
 		(embed, G_CALLBACK (ephy_rss_ge_context_cb), window);
-		
+
 	/* destroy data */
 	g_object_set_data (G_OBJECT (embed), FEEDLIST_DATA_KEY, NULL);
 }
@@ -376,28 +359,20 @@ ephy_rss_create_statusbar_icon (EphyWindow *window,
 {
 	EphyStatusbar *statusbar;
 	GtkWidget *icon;
-	char *tooltip;
 
 	statusbar = EPHY_STATUSBAR (ephy_window_get_statusbar (window));
 	g_return_if_fail (statusbar != NULL);
 
-	data->frame = gtk_frame_new (NULL);
-	/* don't show the frame */
-
 	data->evbox = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (data->evbox), FALSE);
-	gtk_container_add (GTK_CONTAINER (data->frame), data->evbox);
-	gtk_widget_show (data->evbox);
 
-	icon = gtk_image_new_from_icon_name (STOCK_ICON, GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name (FEED_ICON, GTK_ICON_SIZE_MENU);
 	gtk_container_add (GTK_CONTAINER (data->evbox), icon);
 	gtk_widget_show (icon);
 
-	tooltip = g_strdup_printf (_("Subscribe to site's news feed"));
-	gtk_tooltips_set_tip (statusbar->tooltips, data->evbox, tooltip, NULL);
-	g_free (tooltip);
+	gtk_widget_set_tooltip_text (data->evbox, _("Subscribe to site's news feed"));
 
-	ephy_statusbar_add_widget (statusbar, data->frame);
+	ephy_statusbar_add_widget (statusbar, data->evbox);
 
 	g_signal_connect_after (data->evbox, "button-press-event",
 				G_CALLBACK (ephy_rss_statusbar_icon_clicked_cb),
@@ -409,16 +384,13 @@ ephy_rss_destroy_statusbar_icon (EphyWindow *window,
 				 WindowData *data)
 {
 	EphyStatusbar *statusbar;
-	
+
 	statusbar = EPHY_STATUSBAR (ephy_window_get_statusbar (window));
 	g_return_if_fail (statusbar != NULL);
 
-	g_return_if_fail (data->frame != NULL);
-	g_return_if_fail (data->evbox != NULL);	
+	g_return_if_fail (data->evbox != NULL);
 
-	gtk_tooltips_set_tip (statusbar->tooltips, GTK_WIDGET (data->evbox), NULL, NULL);
-
-	ephy_statusbar_remove_widget (statusbar, GTK_WIDGET (data->frame));
+	ephy_statusbar_remove_widget (statusbar, GTK_WIDGET (data->evbox));
 }
 
 /* Create the menu item to subscribe to an rss feed */
@@ -459,7 +431,7 @@ impl_attach_window (EphyExtension *ext,
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyLinkPopup",
 			       "RssSubscribe", "RssSubscribe",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
-			       
+
 	/* store data */
 	data = g_new (WindowData, 1);
 
@@ -468,18 +440,18 @@ impl_attach_window (EphyExtension *ext,
 	data->info_action = gtk_action_group_get_action (action_group, "RssInfo");
 	data->subscribe_action = gtk_action_group_get_action (action_group, "RssSubscribe");
 	data->ui_id = ui_id;
-		
+
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
 				(GDestroyNotify) g_free);
 
 	g_object_set_data (G_OBJECT (window), EPHY_RSS_EXTENSION_DATA_KEY, extension);
-	
+
 	/* Create the status bar icon */
 	ephy_rss_create_statusbar_icon (window, data);
 
 	/* Register for tab switch events */
 	ephy_rss_sync_active_tab (window, NULL, NULL);
-	g_signal_connect_after (window, "notify::active-tab",
+	g_signal_connect_after (window, "notify::active-child",
 				G_CALLBACK (ephy_rss_sync_active_tab), NULL);
 }
 
@@ -519,15 +491,15 @@ ephy_rss_extension_init (EphyRssExtension *extension)
 	DBusGConnection *connection;
 	GError *error = NULL;
 	extension->priv = EPHY_RSS_EXTENSION_GET_PRIVATE (extension);
-		
+
 	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (connection == NULL)
 	{
 		LOG ("No connection to dbus:%s", error->message);
 		g_error_free (error);
 		return;
-    }
-    	
+	}
+
 	extension->priv->proxy = dbus_g_proxy_new_for_name (connection,
                                      RSS_DBUS_SERVICE,
                                      RSS_DBUS_OBJECT_PATH,
@@ -540,7 +512,7 @@ ephy_rss_extension_finalize (GObject *object)
 	EphyRssExtension *extension = EPHY_RSS_EXTENSION (object);
 
 	g_object_unref (extension->priv->proxy);
-	
+
 	/* Dispose the dialog */
 	if (extension->priv->dialog != NULL)
 	{
@@ -584,7 +556,7 @@ ephy_rss_extension_get_type (void)
 GType
 ephy_rss_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyRssExtensionClass),
 		NULL, /* base_init */
@@ -597,7 +569,7 @@ ephy_rss_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_rss_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_rss_extension_iface_init,
 		NULL,
