@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp 1680 2008-02-27 15:20:12Z wbolster $
+ *  $Id: mozilla-helpers.cpp 1731 2008-05-18 21:51:32Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -27,6 +27,11 @@
 
 #include <glib/gi18n-lib.h>
 
+#ifdef XPCOM_GLUE
+#include <nsXPCOMGlue.h>
+#include <gtkmozembed_glue.cpp>
+#endif
+
 #include <nsStringAPI.h>
 
 #include <gtkmozembed.h>
@@ -103,9 +108,8 @@ GetStylesheets (EphyEmbed *aEmbed,
 	NS_ENSURE_TRUE (aEmbed, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIWebBrowser> browser;
-	gtk_moz_embed_get_nsIWebBrowser (
-			GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (aEmbed))),
-			getter_AddRefs (browser));
+	gtk_moz_embed_get_nsIWebBrowser (GTK_MOZ_EMBED (gtk_bin_get_child (GTK_BIN (aEmbed))),
+					 getter_AddRefs (browser));
 	NS_ENSURE_TRUE (browser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIDOMWindow> domWindow;
@@ -291,3 +295,25 @@ mozilla_set_stylesheet (EphyEmbed *aEmbed,
 		item->SetDisabled (strcmp (cTitle.get(), aSelected->mName) != 0);
 	}
 }
+
+gboolean
+mozilla_glue_startup (void)
+{
+#ifdef XPCOM_GLUE
+	static const GREVersionRange greVersion = {
+	  "1.9a", PR_TRUE,
+	  "2", PR_TRUE
+	};
+	char xpcomLocation[4096];
+
+	if (NS_FAILED (GRE_GetGREPathWithProperties(&greVersion, 1, nsnull, 0, xpcomLocation, sizeof (xpcomLocation))) ||
+	    NS_FAILED (XPCOMGlueStartup (xpcomLocation)) ||
+	    NS_FAILED (GTKEmbedGlueStartup ()) ||
+	    NS_FAILED (GTKEmbedGlueStartupInternal()))
+                return FALSE;
+
+        return TRUE;
+#else
+        return TRUE;
+#endif /* XPCOM_GLUE */
+}
