@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2004 Crispin Flowerday
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sidebar-commands.c,v 1.2 2005/01/05 21:07:49 jframeau Exp $
+ *  $Id: sidebar-commands.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "sidebar-commands.h"
 
@@ -39,18 +37,6 @@
  */
 #include <glib/gi18n.h>
 
-static EphyEmbedEvent *
-get_event_info (EphyWindow *window)
-{
-	EphyEmbedEvent *info;
-
-	info = EPHY_EMBED_EVENT (g_object_get_data
-		(G_OBJECT (window), "context_event"));
-	g_return_val_if_fail (info != NULL, NULL);
-
-	return info;
-}
-
 void
 sidebar_cmd_file_save_as (GtkAction *action,
 			  EphySidebarEmbed *sidebar)
@@ -87,7 +73,7 @@ save_property_url (GtkAction *action,
 		   gboolean ask_dest,
 		   const char *property)
 {
-	EphyEmbedEvent *info;
+	EphyEmbedEvent *event;
 	const char *location;
 	const GValue *value;
 	EphyEmbedPersist *persist;
@@ -99,8 +85,10 @@ save_property_url (GtkAction *action,
 
 	window = ephy_sidebar_embed_get_window (sidebar);
 
-	info = get_event_info (window);
-	ephy_embed_event_get_property (info, property, &value);
+	event = ephy_window_get_context_event (window);
+	if (event == NULL) return;
+
+	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
