@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
- *  Copyright (C) 2004 Justin Wake
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
+ *  Copyright © 2004 Justin Wake
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-groups-extension.c,v 1.2 2004/09/26 16:07:59 chpe Exp $
+ *  $Id: ephy-tab-groups-extension.c 1621 2007-11-03 21:52:10Z diegoe $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab-groups-extension.h"
 #include "ephy-tab-grouper.h"
@@ -47,7 +45,7 @@ ephy_tab_groups_extension_get_type (void)
 GType
 ephy_tab_groups_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyTabGroupsExtensionClass),
 		NULL,	/* base_init */
@@ -55,12 +53,12 @@ ephy_tab_groups_extension_register_type (GTypeModule *module)
 		(GClassInitFunc) ephy_tab_groups_extension_class_init,
 		NULL,
 		NULL, /* class_data */
-		sizeof (EphyTab),
+		sizeof (EphyTabGroupsExtension),
 		0,	/* n_preallocs */
 		(GInstanceInitFunc) ephy_tab_groups_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_tab_groups_extension_iface_init,
 		NULL,
@@ -104,7 +102,7 @@ impl_detach_window (EphyExtension *ext,
 static void
 ephy_tab_groups_extension_init (EphyTabGroupsExtension *extension)
 {
-	LOG ("EphyTabGroupsExtension initialising")
+	LOG ("EphyTabGroupsExtension initialising");
 }
 
 static void
