@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2004, 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,16 +15,20 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.h,v 1.6 2005/03/02 14:01:30 chpe Exp $
+ *  $Id: ephy-file-helpers.h 1672 2008-02-18 19:08:12Z cosimoc $
  */
 
 #ifndef EPHY_FILE_HELPERS_H
 #define EPHY_FILE_HELPERS_H
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <gio/gio.h>
+#include <gtk/gtkwidget.h>
+
+extern GQuark ephy_file_helpers_error_quark;
+#define EPHY_FILE_HELPERS_ERROR_QUARK	(ephy_file_helpers_error_quark)
 
 G_BEGIN_DECLS
 
@@ -35,16 +39,21 @@ typedef enum
 	EPHY_MIME_PERMISSION_UNKNOWN	= 3
 } EphyMimePermission;
 
+gboolean    ephy_file_helpers_init       (const char *profile_dir,
+					  gboolean private_profile,
+					  gboolean keep_temp_dir,
+					  GError **error);
+
 const char *ephy_file                    (const char *filename);
 
 const char *ephy_dot_dir                 (void);
 
-void        ephy_file_helpers_init       (void);
-
 void        ephy_file_helpers_shutdown   (void);
 
 char       *ephy_file_downloads_dir      (void);
 
+char	   *ephy_file_get_downloads_dir	 (void);
+
 char       *ephy_file_desktop_dir	 (void);
 
 const char *ephy_file_tmp_dir	 	 (void);
@@ -52,30 +61,42 @@ const char *ephy_file_tmp_dir	 	 (void);
 char       *ephy_file_tmp_filename	 (const char *base,
 					  const char *extension);
 
-gboolean    ephy_ensure_dir_exists       (const char *dir);
+gboolean    ephy_ensure_dir_exists       (const char *dir,
+					  GError **);
 
 GSList     *ephy_file_find               (const char *path,
 				          const char *fname,
 				          gint maxdepth);
 
-gboolean    ephy_file_switch_temp_file   (const char *filename,
-					  const char *filename_temp);
+gboolean    ephy_file_switch_temp_file (GFile *file,
+					GFile *file_temp);
 
-void	    ephy_file_delete_on_exit	 (const char *path);
+void	    ephy_file_delete_on_exit	 (GFile *file);
+
+void	    ephy_file_add_recent_item	 (const char *uri,
+					  const char *mime_type);
 
 EphyMimePermission ephy_file_check_mime	 (const char *mime_type);
 
 gboolean    ephy_file_launch_desktop_file (const char *filename,
-					   guint32 user_time);
+					   const char *parameter,
+					   guint32 user_time,
+					   GtkWidget *widget);
 
-gboolean    ephy_file_launch_application (GnomeVFSMimeApplication *application,
-					  const char *parameter,
-					  guint32 user_time);
+gboolean    ephy_file_launch_application (GAppInfo *app,
+					  GList *files,
+					  guint32 user_time,
+					  GtkWidget *parent);
 
 gboolean    ephy_file_launch_handler	 (const char *mime_type,
-					  const char *address,
+					  GFile *file,
 					  guint32 user_time);
 
+gboolean    ephy_file_browse_to		 (GFile *file,
+					  guint32 user_time);
+
+void	   ephy_file_delete_directory	 (const char *path);
+
 G_END_DECLS
 
 #endif /* EPHY_FILE_HELPERS_H */
